# chem-ant

Select materials to output molecules similar to the target molecule with MCTS Solver and Genetic Programming.
This is a part of [Chess-Ant](https://github.com/akuroiwa/chess-ant) project.
